@@ -234,4 +234,49 @@ terms_y <- function(x) {
 }
 
 
+# ------------------------------------------------------------------------------
 
+check_final_param <- function(x) {
+  if (is.null(x)) {
+    return(invisible(x))
+  }
+  if (!is.list(x) & !tibble::is_tibble(x)) {
+    rlang::abort("The parameter object should be a list or tibble")
+  }
+  if (tibble::is_tibble(x) && nrow(x) > 1) {
+    rlang::abort("The parameter tibble should have a single row.")
+  }
+  if (tibble::is_tibble(x)) {
+    x <- as.list(x)
+  }
+  if (length(names) == 0 || any(names(x) == "")) {
+    rlang::abort("All values in `parameters` should have a name.")
+  }
+
+  invisible(x)
+}
+
+update_main_parameters <- function(args, param) {
+
+  if (length(param) == 0) {
+    return(args)
+  }
+  if (length(args) == 0) {
+    return(param)
+  }
+
+  # In case an engine argument is included:
+  has_extra_args <- !(names(param) %in% names(args))
+  extra_args <- names(param)[has_extra_args]
+  if (any(has_extra_args)) {
+    rlang::abort(
+      paste("At least one argument is not a main argument:",
+            paste0("`", extra_args, "`", collapse = ", "))
+    )
+  }
+  param <- param[!has_extra_args]
+
+
+
+  args <- utils::modifyList(args, param)
+}
