@@ -77,7 +77,7 @@
 #' \Sexpr[results=rd]{parsnip:::show_fit(parsnip:::mlp(mode = "regression"), "nnet")}
 #'
 #' @importFrom purrr map_lgl
-#' @seealso [varying()], [fit()]
+#' @seealso [[fit()]
 #' @examples
 #' mlp(mode = "classification", penalty = 0.01)
 #' # Parameters can be represented by a placeholder:
@@ -139,10 +139,16 @@ print.mlp <- function(x, ...) {
 #' @export
 update.mlp <-
   function(object,
+           parameters = NULL,
            hidden_units = NULL, penalty = NULL, dropout = NULL,
            epochs = NULL, activation = NULL,
            fresh = FALSE, ...) {
     update_dot_check(...)
+
+    if (!is.null(parameters)) {
+      parameters <- check_final_param(parameters)
+    }
+
     args <- list(
       hidden_units = enquo(hidden_units),
       penalty      = enquo(penalty),
@@ -151,6 +157,8 @@ update.mlp <-
       activation   = enquo(activation)
     )
 
+    args <- update_main_parameters(args, parameters)
+
     # TODO make these blocks into a function and document well
     if (fresh) {
       object$args <- args
@@ -381,7 +389,7 @@ nnet_softmax <- function(results, object) {
 
   results <- apply(results, 1, function(x) exp(x)/sum(exp(x)))
   results <- t(results)
-  names(results) <- paste0(".pred_", object$lvl)
+  colnames(results) <- object$lvl
   results <- as_tibble(results)
   results
 }
