@@ -19,11 +19,11 @@
 #' This function can be useful when you need to understand how
 #'  `parsnip` goes from a generic model specific to a model fitting
 #'  function.
-#'  
+#'
 #' **Note**: this function is used internally and users should only use it
 #'  to understand what the underlying syntax would be. It should not be used
-#'  to modify the model specification. 
-#'  
+#'  to modify the model specification.
+#'
 #' @examples
 #' lm_spec <- linear_reg(penalty = 0.01)
 #'
@@ -41,7 +41,7 @@
 #'
 #' @export
 
-translate <- function (x, ...)
+translate <- function(x, ...)
   UseMethod("translate")
 
 #' @importFrom utils getFromNamespace
@@ -53,29 +53,34 @@ translate.default <- function(x, engine = x$engine, ...) {
   if (is.null(engine))
     stop("Please set an engine.", call. = FALSE)
 
+  mod_name <- specific_model(x)
+
   x$engine <- engine
   x <- check_engine(x)
 
-  if (is.null(x$method))
-    x <- get_method(x, engine, ...)
+  if (x$mode == "unknown") {
+    stop("Model code depends on the mode; please specify one.", call. = FALSE)
+  }
 
-  arg_key <- get_module(specific_model(x))
+  if (is.null(x$method))
+    x$method <- get_model_spec(mod_name, x$mode, engine)
+
+  arg_key <- get_args(mod_name, engine)
 
   # deharmonize primary arguments
-  actual_args <- deharmonize(x$args, arg_key, x$engine)
+  actual_args <- deharmonize(x$args, arg_key)
 
   # check secondary arguments to see if they are in the final
   # expression unless there are dots, warn if protected args are
   # being altered
-  eng_arg_key <- arg_key[[x$engine]]
-  x$eng_args <- check_eng_args(x$eng_args, x$method$fit, eng_arg_key)
+  x$eng_args <- check_eng_args(x$eng_args, x$method$fit, arg_key$original)
 
   # keep only modified args
-  modifed_args <- !vapply(actual_args, null_value, lgl(1))
+  modifed_args <- !purrr::map_lgl(actual_args, null_value)
   actual_args <- actual_args[modifed_args]
 
   # look for defaults if not modified in other
-  if(length(x$method$fit$defaults) > 0) {
+  if (length(x$method$fit$defaults) > 0) {
     in_other <- names(x$method$fit$defaults) %in% names(x$eng_args)
     x$defaults <- x$method$fit$defaults[!in_other]
   }
@@ -89,40 +94,6 @@ translate.default <- function(x, engine = x$engine, ...) {
   x
 }
 
-get_method <- function(x, engine = x$engine, ...) {
-  check_empty_ellipse(...)
-  x$engine <- engine
-  x <- check_engine(x)
-  x$method <- get_model_info(x, x$engine)
-  x
-}
-
-
-get_module <- function(nm) {
-  arg_key <- try(
-    getFromNamespace(
-      paste0(nm, "_arg_key"),
-      ns = "parsnip"
-    ),
-    silent = TRUE
-  )
-  if(inherits(arg_key, "try-error")) {
-    arg_key <- try(
-      get(paste0(nm, "_arg_key")),
-      silent = TRUE
-    )
-  }
-  if(inherits(arg_key, "try-error")) {
-    stop(
-      "Cannot find the model code: `",
-      paste0(nm, "_arg_key"),
-      "`", call. = FALSE
-    )
-  }
-  arg_key
-}
-
-
 #' @export
 print.model_spec <- function(x, ...) {
   cat("Model Specification (", x$mode, ")\n\n", sep = "")
@@ -144,3 +115,63 @@ check_mode <- function(object, lvl) {
   }
   object
 }
+
+# ------------------------------------------------------------------------------
+# new code for revised model data structures
+
+get_model_spec <- function(model, mode, engine) {
+  m_env <- get_model_env()
+  env_obj <- rlang::env_names(m_env)
+  env_obj <- grep(model, env_obj, value = TRUE)
+
+  res <- list()
+  res$libs <-
+    rlang::env_get(m_env, paste0(model, "_pkgs")) %>%
+    dplyr::filter(engine == !!engine) %>%
+    purrr::pluck("pkg") %>%
+    purrr::pluck(1)
+
+  res$fit <-
+    rlang::env_get(m_env, paste0(model, "_fit")) %>%
+    dplyr::filter(mode == !!mode & engine == !!engine) %>%
+    dplyr::pull(value) %>%
+    purrr::pluck(1)
+
+  pred_code <-
+    rlang::env_get(m_env, paste0(model, "_predict")) %>%
+    dplyr::filter(mode == !!mode & engine == !!engine) %>%
+    dplyr::select(-engine, -mode)
+
+  res$pred <- pred_code[["value"]]
+  names(res$pred) <- pred_code$type
+
+  res
+}
+
+get_args <- function(model, engine) {
+  m_env <- get_model_env()
+  rlang::env_get(m_env, paste0(model, "_args")) %>%
+    dplyr::filter(engine == !!engine) %>%
+    dplyr::select(-engine)
+}
+
+# to replace harmonize
+deharmonize <- function(args, key) {
+  if (length(args) == 0)
+    return(args)
+  parsn <- tibble(parsnip = names(args), order = seq_along(args))
+  merged <-
+    dplyr::left_join(parsn, key, by = "parsnip") %>%
+    dplyr::arrange(order)
+  # TODO correct for bad merge?
+
+  names(args) <- merged$original
+  args[!is.na(merged$original)]
+}
+
+add_methods <- function(x, engine) {
+  x$engine <- engine
+  x <- check_engine(x)
+  x$method <- get_model_spec(specific_model(x), x$mode, x$engine)
+  x
+}
