@@ -7,9 +7,9 @@ library(tibble)
 
 context("multinom regression execution with glmnet")
 
-ctrl <- fit_control(verbosity = 1, catch = FALSE)
-caught_ctrl <- fit_control(verbosity = 1, catch = TRUE)
-quiet_ctrl <- fit_control(verbosity = 0, catch = TRUE)
+ctrl <- control_parsnip(verbosity = 1, catch = FALSE)
+caught_ctrl <- control_parsnip(verbosity = 1, catch = TRUE)
+quiet_ctrl <- control_parsnip(verbosity = 0, catch = TRUE)
 
 rows <- c(1, 51, 101)
 
@@ -121,9 +121,10 @@ test_that('glmnet probabilities, mulitiple lambda', {
     multi_predict(xy_fit, iris[rows, 1:4], penalty = lams, type = "prob")$.pred
   )
 
-  mult_class <- names(mult_probs)[apply(mult_probs, 1, which.max)]
+  mult_class <- factor(names(mult_probs)[apply(mult_probs, 1, which.max)],
+                       levels = xy_fit$lvl)
   mult_class <- tibble(
-    .pred = mult_class,
+    .pred_class = mult_class,
     penalty = rep(lams, each = 3),
     row = rep(1:3, 2)
   )
@@ -150,38 +151,11 @@ test_that('glmnet probabilities, mulitiple lambda', {
 
 })
 
-# ------------------------------------------------------------------------------
-
-test_that('glmnet grid reduction', {
-  reg_grid <- expand.grid(penalty = 1:3, mixture = (1:5)/5)
-  reg_grid_smol <- min_grid(multinom_reg() %>% set_engine("glmnet"), reg_grid)
-
-  expect_equal(reg_grid_smol$penalty, rep(3, 5))
-  expect_equal(reg_grid_smol$mixture, (1:5)/5)
-  for (i in 1:nrow(reg_grid_smol)) {
-    expect_equal(reg_grid_smol$.submodels[[i]], list(penalty = 1:2))
-  }
-
-  reg_ish_grid <- expand.grid(penalty = 1:3, mixture = (1:5)/5)[-3,]
-  reg_ish_grid_smol <- min_grid(multinom_reg() %>% set_engine("glmnet"), reg_ish_grid)
-
-  expect_equal(reg_ish_grid_smol$penalty, c(2, rep(3, 4)))
-  expect_equal(reg_ish_grid_smol$mixture, (1:5)/5)
-  expect_equal(reg_ish_grid_smol$.submodels[[1]], list(penalty = 1))
-  for (i in 2:nrow(reg_ish_grid_smol)) {
-    expect_equal(reg_ish_grid_smol$.submodels[[i]], list(penalty = 1:2))
-  }
-
-  reg_grid_extra <- expand.grid(penalty = 1:3, mixture = (1:5)/5, blah = 10:12)
-  reg_grid_extra_smol <- min_grid(multinom_reg() %>% set_engine("glmnet"), reg_grid_extra)
-
-  expect_equal(reg_grid_extra_smol$penalty, rep(3, 15))
-  expect_equal(reg_grid_extra_smol$mixture, rep((1:5)/5, each = 3))
-  expect_equal(reg_grid_extra_smol$blah, rep(10:12, 5))
-  for (i in 1:nrow(reg_grid_extra_smol)) {
-    expect_equal(reg_grid_extra_smol$.submodels[[i]], list(penalty = 1:2))
-  }
-
+test_that("class predictions are factors with all levels", {
+  basic <- multinom_reg() %>% set_engine("glmnet") %>% fit(Species ~ ., data = iris)
+  nd <- iris[iris$Species == "setosa", ]
+  yhat <- predict(basic, new_data = nd, penalty = .1)
+  yhat_multi <- multi_predict(basic, new_data =  nd, penalty = .1)$.pred
+  expect_is(yhat_multi[[1]]$.pred_class, "factor")
+  expect_equal(levels(yhat_multi[[1]]$.pred_class), levels(iris$Species))
 })
-
-
