@@ -19,9 +19,9 @@ lc_ranger <- rand_forest(mode = "classification") %>% set_engine("ranger", seed
 bad_ranger_cls <- rand_forest(mode = "classification") %>% set_engine("ranger", replace = "bad")
 bad_rf_cls <- rand_forest(mode = "classification") %>% set_engine("ranger", sampsize = -10)
 
-ctrl <- fit_control(verbosity = 1, catch = FALSE)
-caught_ctrl <- fit_control(verbosity = 1, catch = TRUE)
-quiet_ctrl <- fit_control(verbosity = 0, catch = TRUE)
+ctrl <- control_parsnip(verbosity = 1, catch = FALSE)
+caught_ctrl <- control_parsnip(verbosity = 1, catch = TRUE)
+quiet_ctrl <- control_parsnip(verbosity = 0, catch = TRUE)
 
 # ------------------------------------------------------------------------------
 
