@@ -11,9 +11,9 @@ complete_form <- Surv(time) ~ group
 surv_basic <- surv_reg() %>% set_engine("survival")
 surv_lnorm <- surv_reg(dist = "lognormal") %>% set_engine("survival")
 
-ctrl <- fit_control(verbosity = 1, catch = FALSE)
-caught_ctrl <- fit_control(verbosity = 1, catch = TRUE)
-quiet_ctrl <- fit_control(verbosity = 0, catch = TRUE)
+ctrl <- control_parsnip(verbosity = 1, catch = FALSE)
+caught_ctrl <- control_parsnip(verbosity = 1, catch = TRUE)
+quiet_ctrl <- control_parsnip(verbosity = 0, catch = TRUE)
 
 # ------------------------------------------------------------------------------
 
